@@ -713,12 +713,12 @@ pub fn SUPPORTED_VERSIONS() -> Vec<PgVersion> {
         PgVersion::new(17, PgMinorVersion::Latest, None),
         PgVersion::new(
             18,
-            PgMinorVersion::Beta(1),
+            PgMinorVersion::Beta(2),
             Some(
                 Url::parse(
-                    "https://ftp.postgresql.org/pub/source/v18beta1/postgresql-18beta1.tar.bz2",
+                    "https://ftp.postgresql.org/pub/source/v18beta2/postgresql-18beta2.tar.bz2",
                 )
-                .expect("malformed pg18beta1 url"),
+                .expect("malformed pg18beta2 url"),
             ),
         ),
     ]
@@ -923,11 +923,14 @@ fn from_empty_env() -> eyre::Result<()> {
     let pg_config = PgConfig::from_env();
     assert!(pg_config.is_err());
 
-    // but now we can
-    std::env::set_var("PGRX_PG_CONFIG_AS_ENV", "true");
-    std::env::set_var("PGRX_PG_CONFIG_VERSION", "PostgresSQL 15.1");
-    std::env::set_var("PGRX_PG_CONFIG_INCLUDEDIR-SERVER", "/path/to/server/headers");
-    std::env::set_var("PGRX_PG_CONFIG_CPPFLAGS", "some cpp flags");
+    // SAFETY: set_var in 2024th edition requires unsafe due to sync issues
+    unsafe {
+        // but now we can
+        std::env::set_var("PGRX_PG_CONFIG_AS_ENV", "true");
+        std::env::set_var("PGRX_PG_CONFIG_VERSION", "PostgresSQL 15.1");
+        std::env::set_var("PGRX_PG_CONFIG_INCLUDEDIR-SERVER", "/path/to/server/headers");
+        std::env::set_var("PGRX_PG_CONFIG_CPPFLAGS", "some cpp flags");
+    }
 
     let pg_config = PgConfig::from_env().unwrap();
     assert_eq!(pg_config.major_version()?, 15, "Major version should match");
