@@ -80,7 +80,7 @@ impl Schema {
         let sql_graph_entity_fn_name =
             quote::format_ident!("__pgrx_internals_schema_{ident}_{postfix}");
         quote! {
-            #[no_mangle]
+            #[unsafe(no_mangle)]
             #[doc(hidden)]
             #[allow(unknown_lints, clippy::no_mangle_with_rust_abi)]
             pub extern "Rust" fn  #sql_graph_entity_fn_name() -> ::pgrx::pgrx_sql_entity_graph::SqlGraphEntity {
