@@ -185,7 +185,7 @@ struct PgListIteratorInt<'a, T> {
     pos: usize,
 }
 
-impl<'a, T> Iterator for PgListIteratorPtr<'a, T> {
+impl<T> Iterator for PgListIteratorPtr<'_, T> {
     type Item = *mut T;
 
     fn next(&mut self) -> Option<Self::Item> {
@@ -195,7 +195,7 @@ impl<'a, T> Iterator for PgListIteratorPtr<'a, T> {
     }
 }
 
-impl<'a, T> Iterator for PgListIteratorOid<'a, T> {
+impl<T> Iterator for PgListIteratorOid<'_, T> {
     type Item = pg_sys::Oid;
 
     fn next(&mut self) -> Option<Self::Item> {
@@ -205,7 +205,7 @@ impl<'a, T> Iterator for PgListIteratorOid<'a, T> {
     }
 }
 
-impl<'a, T> Iterator for PgListIteratorInt<'a, T> {
+impl<T> Iterator for PgListIteratorInt<'_, T> {
     type Item = i32;
 
     fn next(&mut self) -> Option<Self::Item> {
